Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1458)

Unified Diff: test/cctest/test-log.cc

Issue 115772: Run script in ProfLazyMode test longer to improve stability. (Closed)
Patch Set: Created 11 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/cctest/test-log.cc
diff --git a/test/cctest/test-log.cc b/test/cctest/test-log.cc
index ada66119d2aca9e8868bff16d939b478645015cf..780a01617caa1405abae96ea9ce0313393fa4c87 100644
--- a/test/cctest/test-log.cc
+++ b/test/cctest/test-log.cc
@@ -165,9 +165,9 @@ static int CheckThatProfilerWorks(int log_pos) {
"for (var i = 0; i < 1000; ++i) { "
"(function(x) { return %d * x; })(i); }",
log_pos);
// Run code for 100 msecs to get some ticks.
const int64_t started_us = i::OS::Ticks();
- while (i::OS::Ticks() - started_us < 100 * 1000) {
+ while (i::OS::Ticks() - started_us < 200 * 1000) {
CompileAndRunScript(script_src.start());
}
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -165,9 +165,9 @@ static int CheckThatProfilerWorks(int log_pos) {
"(function(x) { return %d * x; })(i); }",
log_pos);
- // Run code for 100 msecs to get some ticks.
+ // Run code for 200 msecs to get some ticks.
const int64_t started_us = i::OS::Ticks();

Powered by Google App Engine
This is Rietveld 408576698